@@ -4,44 +4,41 @@
 
 import numpy
 from hydrat.classifier.abstract import Learner, Classifier
+from hydrat.common.pb import ProgressIter
 
 class BinaryLearner(Learner):
-  __name__ = "binarized"
-
   def __init__(self, learner):
+    self.__name__ = learner.__name__
     Learner.__init__(self)
     self.learner = learner
 
-  def _learn(self, feature_map, class_map):
+  def _params(self):
+    params = dict(self.learner.params)
+    params['multiclass'] = 'binarized'
+    return params
+
+  def _learn(self, feature_map, class_map, **kwargs):
     num_classes = class_map.shape[1]
     classifiers = []
-    for cl in range(num_classes):
+    for cl in ProgressIter(range(num_classes),label='Binary Learn'):
       mask = class_map[:,cl]
       # Build a two-class task
       # The second class is the "True" class
       submap = numpy.vstack((numpy.invert(mask),mask)).transpose()
-      classifiers.append(self.learner(feature_map, submap))
+      classifiers.append(self.learner(feature_map, submap, **kwargs))
     return BinaryClassifier(classifiers, self.learner.__name__)
 
-  def _params(self):
-    learner_desc = self.learner.desc
-    params = dict( learner = learner_desc[0]
-                 , learner_params = learner_desc[1]
-                 )
-    return params
-      
-
 class BinaryClassifier(Classifier):
   def __init__(self, classifiers, name):
-    self.__name__ = name + '_bin'
+    self.__name__ = name
     Classifier.__init__(self)
     self.classifiers = classifiers
 
-  def _classify(self, feature_map):
+  def _classify(self, feature_map, **kwargs):
     outcomes = []
-    for c in self.classifiers:
+    for c in ProgressIter(self.classifiers, label="Binary Classify"):
       # We only want the members of the second class
-      r = c(feature_map)
+      r = c(feature_map, **kwargs)
       outcomes.append(r[:,1])
 
     result = numpy.vstack(outcomes).transpose()
