@@ -1,7 +1,13 @@
 import progressbar as pb
+ENABLED = True
 
 def get_widget(label):
-  return [ label, ' ', pb.Percentage(), ' ', pb.Bar(marker='>',left='[',right=']'), ' ', pb.ETA() ]
+  return [ label, ' ', Proportion(), ' ', pb.Bar(marker='>',left='[',right=']'), ' ', pb.ETA() ]
+
+class Proportion(pb.ProgressBarWidget):
+    "Proportion done."
+    def update(self, pbar):
+        return '%d/%d' % (pbar.currval, pbar.maxval)
 
 class ProgressBar(pb.ProgressBar):
   def __enter__(self):
@@ -11,6 +17,14 @@ class ProgressBar(pb.ProgressBar):
   def __exit__(self, exc_type, exc_value, traceback):
     self.finish()
 
+  def _need_update(self):
+    # Always update, since we mostly use this on slow-running tasks
+    return True
+
+  def update(self, value):
+    if ENABLED:
+      pb.ProgressBar.update(self, value)
+
 class ProgressIter(object):
   def __init__(self, sequence, label='Progress'):
     self.seq = iter(sequence)
